==> oauth_server_sso-7.x-1.1.tar.gz: oauth_server_sso/includes/handler.php <==
<?php
    class handler{
    static function generateRandom($length=30) {
        $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
		$charactersLength = strlen($characters);
		$randomString = '';

        for ($i = 0; $i < $length; $i++) {
			$randomString .= $characters[rand(0, $charactersLength - 1)];
		}
		return $randomString;
    }

    static function oauth_server_sso_validate_code($code, $request_code,$request_time)
    {
        $current_time = time();
        if($current_time - $request_time >=400)
        {
            echo "Your authentication code has expired. Please try again.";exit;
          }
          if($code == $request_code)
          {
              variable_set('oauth_server_sso_code','');
          }
          else{
              print_r("Incorrect Code");exit;
          }
    }

    static function ValidateAccessToken($accessToken, $request_time)
    {
        $current_time = time();
        if($current_time - $request_time >=900)
        {
            echo "Your access token has expired. Please try again.";exit;
        }
    }

    static function oauth_server_sso_validate_clientSecret($client_secret)
    {
        $secret_stored = variable_get('oauth_server_sso_client_secret','');
        if($secret_stored != '')
        {
            if($client_secret != $secret_stored)
            {
                print_r('Client Secret mismatch');exit;
            }
        }
        else{
            print_r('Client Secret is not configured');exit;
        }
    }
    static function oauth_server_sso_validate_grant($grant_type)
    {
        if($grant_type != "authorization_code")
        {
            print_r("Only Authorization Code grant type supported");exit;
        }
    }
    static function oauth_server_sso_validate_clientId($client_id)
    {
        $id_stored = variable_get('oauth_server_sso_client_id','');
        if($id_stored != '')
        {
            if($client_id != $id_stored)
            {
                print_r('Client ID mismatch');exit;
            }
        }
        else{
            print_r('Client ID is not configured');exit;
        }
    }

    static function oauth_server_sso_validate_redirectUrl($redirect_uri)
    {
        $redirect_url_stored = variable_get('oauth_server_sso_redirect_url','');
        if($redirect_url_stored != '')
        {
            if($redirect_uri != $redirect_url_stored)
            {
                print_r('Redirect URL mismatch');exit;
            }
        }
        else{
            print_r('Redirect URL is not configured');exit;
        }
    }
}

?>

==> oauth_server_sso-7.x-1.3.tar.gz: oauth_server_sso/includes/handler.php <==
<?php
    class handler{
    static function generateRandom($length=30) {
        $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
		$charactersLength = strlen($characters);
		$randomString = '';

        for ($i = 0; $i < $length; $i++) {
			$randomString .= $characters[rand(0, $charactersLength - 1)];
		}
		return $randomString;
    }

    static function oauth_server_sso_validate_code($code, $request_code,$request_time,$user)
    {
        $current_time = time();
        if($current_time - $request_time >=90)
          {
            echo "Your authentication code has expired. Please try again.";exit;
          }
          if($code == $request_code)
          {
              variable_set('oauth_server_sso_code','');
          }
          else{
              print_r("Incorrect Code");exit;
          }
          DBQueries ::insert_code_from_user_id('', $user);
    }

    static function ValidateAccessToken($accessToken, $request_time)
    {
        $current_time = time();
        if($current_time - $request_time >=900)
        {
            echo "Your access token has expired. Please try again.";exit;
        }
    }

    static function oauth_server_sso_validate_clientSecret($client_secret)
    {
        $secret_stored = variable_get('oauth_server_sso_client_secret','');
        if($secret_stored != '')
        {
            if($client_secret != $secret_stored)
            {
                print_r('Client Secret mismatch');exit;
            }
        }
        else{
            print_r('Client Secret is not configured');exit;
        }
    }
    static function oauth_server_sso_validate_grant($grant_type)
    {
        if($grant_type != "authorization_code")
        {
            print_r("Only Authorization Code grant type supported");exit;
        }
    }
    static function oauth_server_sso_validate_clientId($client_id)
    {
        $id_stored = variable_get('oauth_server_sso_client_id','');
        if($id_stored != '')
        {
            if($client_id != $id_stored)
            {
                print_r('Client ID mismatch');exit;
            }
        }
        else{
            print_r('Client ID is not configured');exit;
        }
    }

    static function oauth_server_sso_validate_redirectUrl($redirect_uri)
    {
        $redirect_url_stored = variable_get('oauth_server_sso_redirect_url','');
        if($redirect_url_stored != '')
        {
            if($redirect_uri != $redirect_url_stored)
            {
                print_r('Redirect URL mismatch');exit;
            }
        }
        else{
            print_r('Redirect URL is not configured');exit;
        }
    }
    static function showErrorMessage( $error, $message, $cause, $closeWindow = FALSE )
    {
        global $base_url;
        $actionToTakeUponWindow = $closeWindow === TRUE ? 'onClick="self.close();"' : 'href="' . $base_url . '/user/login"';
        echo '<div style="font-family:Calibri;padding:0 3%;">';
        echo '<div style="color: #a94442;background-color: #f2dede;padding: 15px;margin-bottom: 20px;text-align:center;border:1px solid #E6B3B2;font-size:18pt;"> ERROR</div>
                                <div style="color: #a94442;font-size:14pt; margin-bottom:20px;"><p><strong>Error: </strong>' .  $error  . '</p>                                      <p>' .  $message  . '</p>
                                    <p><strong>Possible Cause: </strong>' .  $cause  . '</p>
                                </div>'
        ;
        exit;
    }
}

?>
